@@ -2,6 +2,7 @@ import asyncio
 from datetime import datetime
 import logging
 import os
+import subprocess
 import tempfile
 import time
 
@@ -85,6 +86,10 @@ def process_file(video_client, minioClient, redis, next_script):
                 res = redis.hdel(EVENTS_KEY_ACTIVE, key)
                 logging.info("%s removed from active list %s", key, res)
                 emit('wf_camera_uploader', {"success": 1}, {"environment": ENVIRONMENT_ID, "type": "success"})
+            except subprocess.CalledProcessError as err:
+                emit('wf_camera_uploader', {"fail": 1}, {"environment": ENVIRONMENT_ID, "type": "error"})
+                minioClient.remove_object(BUCKET_NAME, key)
+                res = redis.hdel(EVENTS_KEY_ACTIVE, key)
             except Exception as e:
                 emit('wf_camera_uploader', {"fail": 1}, {"environment": ENVIRONMENT_ID, "type": "error"})
                 raise e
